@@ -23,6 +23,7 @@
 #include <init.h>
 #include <mci.h>
 #include <io.h>
+#include <net.h>
 #include <sizes.h>
 
 #include <mach/clock.h>
@@ -93,6 +94,9 @@ static int cfa10036_devices_init(void)
 	add_generic_device("mxs_mci", 0, NULL, IMX_SSP0_BASE, SZ_8K,
 			   IORESOURCE_MEM, &mci_pdata);
 
+	add_generic_device("ocotp", 0, NULL, IMX_OCOTP_BASE, SZ_8K,
+			   IORESOURCE_MEM, NULL);
+
 	return 0;
 }
 device_initcall(cfa10036_devices_init);
