@@ -24,7 +24,7 @@
 #include <fs.h>
 #include <environment.h>
 #include <usb/ulpi.h>
-#include <mach/imx-regs.h>
+#include <mach/imx31-regs.h>
 #include <mach/iomux-mx31.h>
 #include <asm/armlinux.h>
 #include <asm-generic/sections.h>
@@ -96,7 +96,7 @@ static void pcm037_usb_init(void)
 	/* Host 2 */
 	tmp = readl(MX31_USB_OTG_BASE_ADDR + 0x8);
 	tmp |= 1 << 11;
-	writel(tmp, IOMUXC_BASE + 0x8);
+	writel(tmp, MX31_IOMUXC_BASE_ADDR + 0x8);
 
 	imx_iomux_mode(IOMUX_MODE(MX31_PIN_USBH2_CLK, IOMUX_CONFIG_FUNC));
 	imx_iomux_mode(IOMUX_MODE(MX31_PIN_USBH2_DIR, IOMUX_CONFIG_FUNC));
