@@ -21,6 +21,7 @@
 #include <mach/hardware.h>
 #include <sizes.h>
 #include <net.h>
+#include <i2c/i2c.h>
 #include <spi/spi.h>
 #include <linux/mtd/mtd.h>
 
@@ -53,6 +54,10 @@ struct atmel_nand_data {
 	u8		bus_width_16;	/* buswidth is 16 bit */
 	u8		ecc_mode;	/* NAND_ECC_* */
 	u8		on_flash_bbt;	/* Use flash based bbt */
+
+	u8		pmecc_corr_cap;
+	u16		pmecc_sector_size;
+	u32		pmecc_lookup_table_offset;
 };
 
 void at91_add_device_nand(struct atmel_nand_data *data);
@@ -71,6 +76,8 @@ struct at91_ether_platform_data {
 
 void at91_add_device_eth(int id, struct at91_ether_platform_data *data);
 
+void at91_add_device_i2c(short i2c_id, struct i2c_board_info *devices, int nr_devices);
+
 /* SDRAM */
 void at91_add_device_sdram(u32 size);
 
