@@ -47,7 +47,7 @@
 
 enum imx21_clks {
 	ckil, ckih, fpm, mpll_sel, spll_sel, mpll, spll, fclk, hclk, ipg, per1,
-	per2, per3, per4, usb_div, nfc_div, clk_max
+	per2, per3, per4, usb_div, nfc_div, lcdc_per_gate, clk_max
 };
 
 static struct clk *clks[clk_max];
@@ -70,6 +70,16 @@ static int imx21_ccm_probe(struct device_d *dev)
 
 	base = dev_request_mem_region(dev, 0);
 
+	writel((1 << 0) | (1 << 1) | (1 << 2) | (1 << 3) | (1 << 4) | (1 << 5) |
+			(1 << 9) | (1 << 10) | (1 << 11) | (1 << 12) |
+			(1 << 13) | (1 << 14) | (1 << 19) | (1 << 22) |
+			(1 << 24) | (1 << 26) |	(1 << 30),
+			base + CCM_PCCR0);
+
+	writel((1 << 23) | (1 << 24) | (1 << 25) | (1 << 26) | (1 << 27) |
+			(1 << 28) | (1 << 29) | (1 << 30) | (1 << 31),
+			base + CCM_PCCR1);
+
 	clks[ckil] = clk_fixed("ckil", lref);
 	clks[ckih] = clk_fixed("ckih", href);
 	clks[fpm] = imx_clk_fixed_factor("fpm", "ckil", 512, 1);
@@ -88,6 +98,7 @@ static int imx21_ccm_probe(struct device_d *dev)
 	clks[per4] = imx_clk_divider("per4", "mpll", base + CCM_PCDR1, 24, 6);
 	clks[usb_div] = imx_clk_divider("usb_div", "spll", base + CCM_CSCR, 26, 3);
 	clks[nfc_div] = imx_clk_divider("nfc_div", "ipg", base + CCM_PCDR0, 12, 4);
+	clks[lcdc_per_gate] = imx_clk_gate("lcdc_per_gate", "per3", base + CCM_PCCR0, 18);
 
 	clkdev_add_physbase(clks[per1], MX21_GPT1_BASE_ADDR, NULL);
 	clkdev_add_physbase(clks[per1], MX21_GPT2_BASE_ADDR, NULL);
@@ -98,18 +109,27 @@ static int imx21_ccm_probe(struct device_d *dev)
 	clkdev_add_physbase(clks[per1], MX21_UART4_BASE_ADDR, NULL);
 	clkdev_add_physbase(clks[per2], MX21_CSPI1_BASE_ADDR, NULL);
 	clkdev_add_physbase(clks[per2], MX21_CSPI2_BASE_ADDR, NULL);
+	clkdev_add_physbase(clks[per2], MX21_CSPI3_BASE_ADDR, NULL);
 	clkdev_add_physbase(clks[ipg], MX21_I2C_BASE_ADDR, NULL);
 	clkdev_add_physbase(clks[ipg], MX21_SDHC1_BASE_ADDR, NULL);
 	clkdev_add_physbase(clks[ipg], MX21_SDHC2_BASE_ADDR, NULL);
-	clkdev_add_physbase(clks[per3], MX21_CSPI3_BASE_ADDR, NULL);
-	clkdev_add_physbase(clks[per3], MX21_LCDC_BASE_ADDR, NULL);
+	clkdev_add_physbase(clks[lcdc_per_gate], MX21_LCDC_BASE_ADDR, NULL);
 
 	return 0;
 }
 
+static __maybe_unused struct of_device_id imx21_ccm_dt_ids[] = {
+	{
+		.compatible = "fsl,imx21-ccm",
+	}, {
+		/* sentinel */
+	}
+};
+
 static struct driver_d imx21_ccm_driver = {
 	.probe	= imx21_ccm_probe,
 	.name	= "imx21-ccm",
+	.of_compatible = DRV_OF_COMPAT(imx21_ccm_dt_ids),
 };
 
 static int imx21_ccm_init(void)
