@@ -2,22 +2,22 @@
 
 static inline struct device_d *imx6_add_uart0(void)
 {
-	return imx_add_uart((void *)MX6_UART1_BASE_ADDR, 0);
+	return imx_add_uart_imx21((void *)MX6_UART1_BASE_ADDR, 0);
 }
 
 static inline struct device_d *imx6_add_uart1(void)
 {
-	return imx_add_uart((void *)MX6_UART2_BASE_ADDR, 1);
+	return imx_add_uart_imx21((void *)MX6_UART2_BASE_ADDR, 1);
 }
 
 static inline struct device_d *imx6_add_uart2(void)
 {
-	return imx_add_uart((void *)MX6_UART3_BASE_ADDR, 2);
+	return imx_add_uart_imx21((void *)MX6_UART3_BASE_ADDR, 2);
 }
 
 static inline struct device_d *imx6_add_uart3(void)
 {
-	return imx_add_uart((void *)MX6_UART4_BASE_ADDR, 3);
+	return imx_add_uart_imx21((void *)MX6_UART4_BASE_ADDR, 3);
 }
 
 static inline struct device_d *imx6_add_mmc0(struct esdhc_platform_data *pdata)
@@ -42,7 +42,7 @@ static inline struct device_d *imx6_add_mmc3(struct esdhc_platform_data *pdata)
 
 static inline struct device_d *imx6_add_fec(struct fec_platform_data *pdata)
 {
-	return imx_add_fec((void *)MX6_ENET_BASE_ADDR, pdata);
+	return imx_add_fec_imx6((void *)MX6_ENET_BASE_ADDR, pdata);
 }
 
 static inline struct device_d *imx6_add_spi0(struct spi_imx_master *pdata)
