@@ -1,10 +1,6 @@
 #ifndef __MACH_IMX53_REGS_H
 #define __MACH_IMX53_REGS_H
 
-#define IMX_TIM1_BASE			0X53FA0000
-#define IMX_WDT_BASE			0X53F98000
-#define IMX_IOMUXC_BASE			0X53FA8000
-
 #define MX53_IROM_BASE_ADDR	0x0
 
 /*
