@@ -1,6 +1,7 @@
 #include <common.h>
 #include <generated/compile.h>
 #include <generated/utsrelease.h>
+#include <of.h>
 
 const char version_string[] =
 	"barebox " UTS_RELEASE " " UTS_VERSION "\n";
@@ -8,7 +9,13 @@ EXPORT_SYMBOL(version_string);
 
 void barebox_banner (void)
 {
-	printf("\n\n%s\n\n", version_string);
-	printf("Board: " CONFIG_BOARDINFO "\n");
-}
+	const char *board;
 
+	board = of_get_model();
+
+	if (!board)
+		board = CONFIG_BOARDINFO;
+
+	printf("\n\n%s\n\n", version_string);
+	printf("Board: %s\n", board);
+}
